@@ -6,6 +6,7 @@ use serde_with::*;
 use crate::Builder;
 
 use super::components::ComponentType;
+use super::user::*;
 use super::Snowflake;
 use serde_repr::*;
 
@@ -18,9 +19,19 @@ pub struct ApplicationCommand {
     #[serde(default)]
     /// ID of command
     pub id: Option<Snowflake>,
+
+    /// the type of command, defaults `1` if not set
+    pub r#type: Option<ApplicationCommandType>,
+
     #[serde_as(as = "Option<DisplayFromStr>")]
     #[serde(default)]
     application_id: Option<Snowflake>,
+
+    #[serde_as(as = "Option<DisplayFromStr>")]
+    #[serde(default)]
+    /// guild id of the command, if not global
+    pub guild_id: Option<Snowflake>,
+
     /// Command name
     pub name: String,
     /// Command description
@@ -32,11 +43,26 @@ pub struct ApplicationCommand {
     default_permission: Option<bool>,
 }
 
+#[derive(Clone, Serialize_repr, Deserialize_repr, Debug, PartialEq)]
+#[repr(u8)]
+#[non_exhaustive]
+/// Type of `ApplicationCommand`
+pub enum ApplicationCommandType{
+    /// Slash commands; a text-based command that shows up when a user types `/` 
+    ChatInput = 1,
+    /// A UI-based command that shows up when you right click or tap on a user
+    User = 2,
+    /// A UI-based command that shows up when you right click or tap on a messages
+    Message = 3,
+}
+
 impl Default for ApplicationCommand {
     fn default() -> Self {
         Self {
             id: None,
+            r#type: Some(ApplicationCommandType::ChatInput),
             application_id: None,
+            guild_id: None,
             name: String::new(),
             description: String::new(),
             options: None,
@@ -45,7 +71,7 @@ impl Default for ApplicationCommand {
     }
 }
 
-#[derive(Clone, Serialize_repr, Deserialize_repr, Debug, PartialEq)]
+#[derive(Clone, Copy, Serialize_repr, Deserialize_repr, Debug, PartialEq)]
 #[repr(u8)]
 #[non_exhaustive]
 /// Type of permission override
@@ -202,24 +228,50 @@ pub struct ApplicationCommandOptionChoice {
     pub value: String,
 }
 
+#[derive(Clone, Serialize, Deserialize, PartialEq, Debug)]
+/// Stripped down version of ResolvedData
+pub struct ResolvedData{
+    /// User map
+    pub users: Option<User>,
+    /// Member map
+    pub members: Option<Member>,
+}
+
+
 #[serde_as]
 #[derive(Clone, Serialize, Deserialize, PartialEq, Debug)]
 /// Representing a slash command
 pub struct ApplicationCommandInteractionData {
+    /// The unique id of the command
     #[serde_as(as = "Option<DisplayFromStr>")]
     #[serde(default)]
-    /// The unique id of the command
     pub id: Option<Snowflake>,
     /// The name of the command
     pub name: Option<String>,
+
+    /// The type of the invoked command
+    pub r#type: Option<ApplicationCommandType>,
+
     /// An array of [`ApplicationCommandInteractionDataOption`]
     pub options: Option<Vec<ApplicationCommandInteractionDataOption>>,
 
+    /// converted users + roles + channels
+    // Not including this yet
+    //pub resolved: Option<ResolvedData>,
+
     /// For components, the component type
     pub component_type: Option<ComponentType>,
 
     /// For components, the custom identifier for the developer
     pub custom_id: Option<String>,
+
+    /// For Select Menus, the selected values
+    pub values: Option<Vec<ApplicationCommandOption>>,
+
+    #[serde_as(as = "Option<DisplayFromStr>")]
+    #[serde(default)]
+    /// For User- and Message Commands, the id of the user or message targeted.
+    pub target_id: Option<Snowflake>
 }
 
 #[derive(Clone, Serialize, Deserialize, PartialEq, Debug)]
@@ -252,13 +304,20 @@ impl Default for SlashCommandDefinitionBuilder {
 
 #[cfg(feature = "extended-handler")]
 impl SlashCommandDefinitionBuilder {
-    /// Name of slash command
+    /// Name of the application command
     pub fn name(mut self, name: impl ToString) -> Self {
         let n = name.to_string();
 
         self.obj.name = n;
         self
     }
+
+    /// Sets the type of command you're defining. See [`ApplicationCommandType`]
+    pub fn command_type(mut self, c_type: ApplicationCommandType) -> Self{
+        self.obj.r#type = Some(c_type);
+        self
+    }
+
     /// Command description
     pub fn description(mut self, desc: impl ToString) -> Self {
         let d = desc.to_string();
