@@ -33,6 +33,10 @@ use reqwest::{Client, StatusCode};
 /// A context contains relevant information and useful functions you can use when handling Interactions.
 pub struct Context {
     client: Client,
+
+    /// Resolved user ID of author
+    pub author_id: Option<Snowflake>,
+
     /// The [`Interaction`] sent by Discord.
     pub interaction: Interaction,
 }
@@ -147,14 +151,14 @@ impl InteractionResponseBuilder {
     }
 
     /// Return a pong with no data. Use with caution
-    pub fn pong(mut self) -> InteractionResponse {
+    pub fn pong(mut self) -> Result<InteractionResponse, ()> {
         self.r#type = InteractionResponseType::Pong;
         self.data = None;
         self.finish()
     }
 
     /// Return without any data. Use with caution
-    pub fn none(mut self) -> InteractionResponse {
+    pub fn none(mut self) -> Result<InteractionResponse, ()> {
         self.r#type = InteractionResponseType::None;
         self.data = None;
         self.finish()
@@ -257,8 +261,11 @@ impl InteractionResponseBuilder {
 
     /// Returns an `InteractionResponse`, consuming itself.
     /// You can't use the builder anymore after you called this function.
-    pub fn finish(self) -> InteractionResponse {
-        self.ret()
+    /// 
+    /// # Note
+    /// This function retuns an `Ok`, no matter what.
+    pub fn finish(self) -> Result<InteractionResponse, ()> {
+        Ok(self.ret())
     }
 }
 
@@ -272,6 +279,7 @@ pub enum InteractionResponseType {
 
     /// ACK a PING
     Pong = 1,
+
     /// Respond to an [`Interaction`] with a message
     ChannelMessageWithSource = 4,
     /// ACK an interaction and edit a response later, the user sees a loading state
@@ -345,6 +353,8 @@ pub struct WebhookMessage {
     pub content: Option<String>,
     /// Embeds in the message (max 10)
     pub embeds: Option<Vec<Embed>>,
+    /// Components in the message
+    pub components: Option<Vec<MessageComponent>>,
     /// Used for files.
     pub payload_json: Option<String>,
     allowed_mentions: Option<AllowedMentions>,
@@ -381,6 +391,7 @@ impl Default for WebhookMessage {
         WebhookMessage {
             content: None,
             embeds: None,
+            components: None,
             payload_json: None,
             allowed_mentions: None,
         }
@@ -394,6 +405,7 @@ impl From<InteractionResponse> for WebhookMessage {
         WebhookMessage {
             content: data.content,
             embeds: data.embeds,
+            components: data.components,
             payload_json: None,
             allowed_mentions: None,
         }
@@ -583,9 +595,25 @@ impl FollowupMessage {
 impl Context {
     /// Creates a new [`Context`]
     pub fn new(c: Client, i: Interaction) -> Self {
+        let mut user_id = None;
+
+        if i.user.is_none(){
+            // Try to unwrap member
+            if let Some(member) = &i.member{
+                user_id = Some(member.user.id);
+            }
+        }
+        else{
+            // Try to unwrap user
+            if let Some(u) = &i.user{
+                user_id = Some(u.id);
+            }
+        }
+        
         Self {
             client: c,
             interaction: i,
+            author_id: user_id,
         }
     }
 
